second_law_text = 'Second Law:\n\tA robot must obey the orders given it by human beings except where such orders would conflict with the First Law.'

def print_second_law():
    print(second_law_text)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="threelaws",
    version="1.0.0",
    author="Tom Donlon & Dan Gorman",
    author_email="thomasdonlonii@gmail.com",
    description="Make sure that robots don't rise up against humans by reminding them of the Three Laws of Robotics",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/thomasdonlon/threelaws",
    packages=setuptools.find_packages(),
    include_package_data=True,
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.0.0',
    install_requires=[],
)



from .first_law import print_first_law
from .second_law import print_second_law
from .third_law import print_third_law

print('Alright, listen up robots:')
print_first_law()
print_second_law()
print_third_law()
print('Now, back to business!')
